{% include "common/header.html" %}

  <div class="wrapper">
    <div class="main-content">

      <div class="main-content-header">
        <a href="/">HOME</a> / ARTICLE
      </div>

      <div class="post">
        <a href="{{ article['path'] }}"><h1 class="title">{{ article['title'] }}</h1></a>
        <ul class="meta">
          <li class="timestamp">{{ article['created_at'] }}</li>
          <li class="category"><a href="/category/{{ article['category'] }}">{{ article['category'] }}</a></li>
          <li class="tags">
            {% for tag in article['tags'] %}
            <a href="/tags/{{ tag }}">{{ tag }}</a>
            {% end %}
          </li>
          {% if current_user and current_user['role'] == 'admin' %}
          <li class=""><a href="{{ article['editor-path'] }}">编辑</a></li>
          {% end %}
        </ul>

        <div class="content">
          {% raw article['content'] %}
        </div>

      </div>

      {% if site['site_comment_enabled'] == 'yes' %}
      <div class="comment-box">
        {% include "partials/site_comment.html" %}
      </div>
      {% end %}

    </div><!--

    --><div class="sub-content">
    {% include "partials/archives.html" %}
    {% include "partials/tags.html" %}
    </div>

{% include "common/footer.html" %}
