  <div class="footer">
    <div class="wrapper">
      <span class="power-by">Powered By </span>
      <span class="engine">
        <a href="http://vanellope.org/" alt="qar/vanellope">VANELLOPE</a>
      </span>
    </div>
  </div><!-- .footer -->

</div><!-- #main-wrapper -->

{% if site['site_tracking_enabled'] == 'yes' %}
  {% include '../partials/site_tracking.html' %}
{% end %}
</body>
</html>
