<div class="widget">
  <div class="widget-header">ADMIN TOOLS</div>
  <div class="widget-body">
    <ul>

      <li><a href="/admin/edit" class="vn-btn btn-primary btn-block"><span>New Post</span></a></li>

    </ul>
  </div>
</div>
