// colors
$theme-green: #428bca;
$theme-color: #428BCA;

// fonts
$font-base-size: 10px;
$font: PingFang SC, Lantinghei SC, Microsoft Yahei, Hiragino Sans GB, Microsoft Sans Serif, WenQuanYi Micro Hei, sans;
$title-size: 2rem;
$brief-size: 1.3rem;
$brief-color: #777;
$meta-color: #1A1A1A;
$meta-size: 1.1rem;
$widget-header-size: 1.3rem;
$widget-body-size: 1.2rem;

// dimensions
$banner-height-lg: 120px;
$main-region-width: 70%;
$sub-region-width: 30%;
$footer-height-lg: 50px;
$group-ele-gap: 1rem;

// viewport dimensions
$large-view: 970px; // min

// Elements
$button-normal-height: 4rem;
