<link rel="apple-touch-icon" sizes="57x57" href="/static/favicon/apple-touch-icon-57x57.png?v=Gvv7MKA3Pb">
<link rel="apple-touch-icon" sizes="60x60" href="/static/favicon/apple-touch-icon-60x60.png?v=Gvv7MKA3Pb">
<link rel="apple-touch-icon" sizes="72x72" href="/static/favicon/apple-touch-icon-72x72.png?v=Gvv7MKA3Pb">
<link rel="apple-touch-icon" sizes="76x76" href="/static/favicon/apple-touch-icon-76x76.png?v=Gvv7MKA3Pb">
<link rel="apple-touch-icon" sizes="114x114" href="/static/favicon/apple-touch-icon-114x114.png?v=Gvv7MKA3Pb">
<link rel="apple-touch-icon" sizes="120x120" href="/static/favicon/apple-touch-icon-120x120.png?v=Gvv7MKA3Pb">
<link rel="apple-touch-icon" sizes="144x144" href="/static/favicon/apple-touch-icon-144x144.png?v=Gvv7MKA3Pb">
<link rel="apple-touch-icon" sizes="152x152" href="/static/favicon/apple-touch-icon-152x152.png?v=Gvv7MKA3Pb">
<link rel="apple-touch-icon" sizes="180x180" href="/static/favicon/apple-touch-icon-180x180.png?v=Gvv7MKA3Pb">
<link rel="icon" type="image/png" href="/static/favicon/favicon-32x32.png?v=Gvv7MKA3Pb" sizes="32x32">
<link rel="icon" type="image/png" href="/static/favicon/android-chrome-192x192.png?v=Gvv7MKA3Pb" sizes="192x192">
<link rel="icon" type="image/png" href="/static/favicon/favicon-96x96.png?v=Gvv7MKA3Pb" sizes="96x96">
<link rel="icon" type="image/png" href="/static/favicon/favicon-16x16.png?v=Gvv7MKA3Pb" sizes="16x16">
<link rel="manifest" href="/static/favicon/manifest.json?v=Gvv7MKA3Pb">
<link rel="mask-icon" href="/static/favicon/safari-pinned-tab.svg?v=Gvv7MKA3Pb" color="#428bca">
<link rel="shortcut icon" href="/static/favicon/favicon.ico?v=Gvv7MKA3Pb">
<meta name="msapplication-TileColor" content="#da532c">
<meta name="msapplication-TileImage" content="/static/favicon/mstile-144x144.png?v=Gvv7MKA3Pb">
<meta name="msapplication-config" content="/static/favicon/browserconfig.xml?v=Gvv7MKA3Pb">
<meta name="theme-color" content="#428bca">
