{% include "common/header.html" %}

<div class="wrapper" ng-controller="editorCtrl">

  <div class="main-content">
    <input class="vn-input" type="text" placeholder="标题" ng-model="title">

    <div class="quill-wrapper post post-editing">
      <textarea id="editor" placeholder="Happy writing" autofocus></textarea>
    </div>
  </div><!-- .main-content -->

  <div class="sub-content">
    <div class="widget admin">
      <div class="widget-body">
        <div class="vn-input-group">
          <input class="vn-input" type="text" ng-model="category" placeholder="分类">
        </div>
        <div class="vn-input-group">
          <input class="vn-input" type="text" ng-model="tags" placeholder="标签">
        </div>

        <div class="vn-input-group">
          <label><input class="vn-input" type="radio" value="draft" ng-model="state" /> 草稿</label>
        </div>
        <div class="vn-input-group">
          <label><input class="vn-input" type="radio" value="published" ng-model="state" /> 发布</label>
        </div>

        <ul class="buttons">
          <li><a href="#" class="vn-btn btn-primary" ng-click="savePost()">保存</a></li>
          <li><a href="#" class="vn-btn btn-primary" ng-show="entry_id" ng-click="deletePost()">移到垃圾箱</a></li>
        </ul>
      </div>
    </div>
  </div><!-- .sub-content -->

</div><!-- .wrapper -->
{% include "common/footer.html" %}
