html, body {
    width: 100%;
    height: 100%;
    margin: 0;
    padding: 0;
    border: none;
}

html {
    font-size: 62.5%;
}


body {
    font-family: $font;

    // https://code.google.com/p/chromium/issues/detail?id=320754
    font-size: 14px;
    //font-size: 1.4rem;

    overflow-x: hidden; // 禁止横向滚动
    overflow-y: auto; // 允许垂直滚动，必要时才显示滚动条
}

ol, ul {
    list-style: none;
    margin: 0;
    padding: 0;
}

a {
    text-decoration: none;
    color: inherit;
}

